@@ -33,7 +33,8 @@ SUBROUTINE do_cond(done)
   !!!
   USE noncollin_module, ONLY : noncolin, i_cons
   USE io_global, ONLY : stdout, ionode, ionode_id
-  USE mp_global, ONLY : nproc, npool, mp_startup
+  USE mp_global, ONLY : mp_startup, npool
+  USE mp_world,  ONLY : world_comm, nproc
   USE paw_onecenter,      ONLY : PAW_potential
   USE paw_variables,      ONLY : okpaw, ddd_PAW
   USE mp
@@ -202,53 +203,53 @@ SUBROUTINE do_cond(done)
 !
 ! ... Broadcast variables
 !
-  CALL mp_bcast( tmp_dir, ionode_id )
-  CALL mp_bcast( prefixt, ionode_id )
-  CALL mp_bcast( prefixl, ionode_id )
-  CALL mp_bcast( prefixs, ionode_id )
-  CALL mp_bcast( prefixr, ionode_id )
-  CALL mp_bcast( band_file, ionode_id )
-  CALL mp_bcast( tran_file, ionode_id )
-  CALL mp_bcast( fil_loc, ionode_id )
-  CALL mp_bcast( save_file, ionode_id )
-  CALL mp_bcast( loop_ek, ionode_id )
-  CALL mp_bcast( lwrite_loc, ionode_id )
-  CALL mp_bcast( lread_loc, ionode_id )
-  CALL mp_bcast( lwrite_cond, ionode_id )
-  CALL mp_bcast( lread_cond, ionode_id )
+  CALL mp_bcast( tmp_dir, ionode_id, world_comm )
+  CALL mp_bcast( prefixt, ionode_id, world_comm )
+  CALL mp_bcast( prefixl, ionode_id, world_comm )
+  CALL mp_bcast( prefixs, ionode_id, world_comm )
+  CALL mp_bcast( prefixr, ionode_id, world_comm )
+  CALL mp_bcast( band_file, ionode_id, world_comm )
+  CALL mp_bcast( tran_file, ionode_id, world_comm )
+  CALL mp_bcast( fil_loc, ionode_id, world_comm )
+  CALL mp_bcast( save_file, ionode_id, world_comm )
+  CALL mp_bcast( loop_ek, ionode_id, world_comm )
+  CALL mp_bcast( lwrite_loc, ionode_id, world_comm )
+  CALL mp_bcast( lread_loc, ionode_id, world_comm )
+  CALL mp_bcast( lwrite_cond, ionode_id, world_comm )
+  CALL mp_bcast( lread_cond, ionode_id, world_comm )
   !!! RECOVER
-  CALL mp_bcast( tran_prefix, ionode_id )
-  CALL mp_bcast( max_seconds, ionode_id )
-  CALL mp_bcast( recover, ionode_id )
+  CALL mp_bcast( tran_prefix, ionode_id, world_comm )
+  CALL mp_bcast( max_seconds, ionode_id, world_comm )
+  CALL mp_bcast( recover, ionode_id, world_comm )
   !!!
-  CALL mp_bcast( ikind, ionode_id )
-  CALL mp_bcast( iofspin, ionode_id )
-  CALL mp_bcast( orbj_in, ionode_id )
-  CALL mp_bcast( orbj_fin, ionode_id )
-  CALL mp_bcast( llocal, ionode_id )
-  CALL mp_bcast( tk_plot, ionode_id )
-  CALL mp_bcast( lorb, ionode_id )
-  CALL mp_bcast( lorb3d, ionode_id )
-  CALL mp_bcast( lcharge, ionode_id )
-  CALL mp_bcast( bdl, ionode_id )
-  CALL mp_bcast( bds, ionode_id )
-  CALL mp_bcast( bdr, ionode_id )
-  CALL mp_bcast( nz1, ionode_id )
-  CALL mp_bcast( energy0, ionode_id )
-  CALL mp_bcast( denergy, ionode_id )
-  CALL mp_bcast( ecut2d, ionode_id )
-  CALL mp_bcast( start_e, ionode_id )
-  CALL mp_bcast( last_e, ionode_id )
-  CALL mp_bcast( ewind, ionode_id )
-  CALL mp_bcast( epsproj, ionode_id )
-  CALL mp_bcast( delgep, ionode_id )
-  CALL mp_bcast( cutplot, ionode_id )
-  CALL mp_bcast( nkpts, ionode_id )
-  CALL mp_bcast( nenergy, ionode_id )
-  CALL mp_bcast( nk1ts, ionode_id )
-  CALL mp_bcast( nk2ts, ionode_id )
-  CALL mp_bcast( k1ts, ionode_id )
-  CALL mp_bcast( k2ts, ionode_id )
+  CALL mp_bcast( ikind, ionode_id, world_comm )
+  CALL mp_bcast( iofspin, ionode_id, world_comm )
+  CALL mp_bcast( orbj_in, ionode_id, world_comm )
+  CALL mp_bcast( orbj_fin, ionode_id, world_comm )
+  CALL mp_bcast( llocal, ionode_id, world_comm )
+  CALL mp_bcast( tk_plot, ionode_id, world_comm )
+  CALL mp_bcast( lorb, ionode_id, world_comm )
+  CALL mp_bcast( lorb3d, ionode_id, world_comm )
+  CALL mp_bcast( lcharge, ionode_id, world_comm )
+  CALL mp_bcast( bdl, ionode_id, world_comm )
+  CALL mp_bcast( bds, ionode_id, world_comm )
+  CALL mp_bcast( bdr, ionode_id, world_comm )
+  CALL mp_bcast( nz1, ionode_id, world_comm )
+  CALL mp_bcast( energy0, ionode_id, world_comm )
+  CALL mp_bcast( denergy, ionode_id, world_comm )
+  CALL mp_bcast( ecut2d, ionode_id, world_comm )
+  CALL mp_bcast( start_e, ionode_id, world_comm )
+  CALL mp_bcast( last_e, ionode_id, world_comm )
+  CALL mp_bcast( ewind, ionode_id, world_comm )
+  CALL mp_bcast( epsproj, ionode_id, world_comm )
+  CALL mp_bcast( delgep, ionode_id, world_comm )
+  CALL mp_bcast( cutplot, ionode_id, world_comm )
+  CALL mp_bcast( nkpts, ionode_id, world_comm )
+  CALL mp_bcast( nenergy, ionode_id, world_comm )
+  CALL mp_bcast( nk1ts, ionode_id, world_comm )
+  CALL mp_bcast( nk2ts, ionode_id, world_comm )
+  CALL mp_bcast( k1ts, ionode_id, world_comm )
+  CALL mp_bcast( k2ts, ionode_id, world_comm )
 
   IF ( .NOT. ionode ) THEN
      IF (nkpts>0) THEN
@@ -262,11 +263,11 @@ SUBROUTINE do_cond(done)
      ALLOCATE( tran_tot(nenergy) )
   ENDIF
   IF (nkpts>0) THEN
-     CALL mp_bcast( xyk, ionode_id )
-     CALL mp_bcast( wkpt, ionode_id )
+     CALL mp_bcast( xyk, ionode_id, world_comm )
+     CALL mp_bcast( wkpt, ionode_id, world_comm )
   ENDIF
-  CALL mp_bcast( earr, ionode_id )
-  CALL mp_bcast( tran_tot, ionode_id )
+  CALL mp_bcast( earr, ionode_id, world_comm )
+  CALL mp_bcast( tran_tot, ionode_id, world_comm )
 
 
 !
@@ -374,35 +375,6 @@ IF (lwrite_cond) then
   return
 endif
 
-IF ( lda_plus_u ) THEN
-   !
-   IF ( U_projection .NE. "pseudo" ) &
-      CALL errore('do_cond','LDA+U works only for "pseudo" projection type',1)
-   !
-   ! report of LDA+U parameters (as in PW/src/summary.f90)
-   IF (lda_plus_u_kind == 0) THEN
-      !
-      WRITE( stdout, '(/,/,5x,"Simplified LDA+U calculation (l_max = ",i1, &
-         ") with parameters (eV):")') Hubbard_lmax
-      WRITE( stdout, '(5x,A)') &
-         "atomic species    L          U    alpha       J0     beta"
-      DO nt = 1, ntyp
-         IF ( Hubbard_U(nt) /= 0.D0 .OR. Hubbard_alpha(nt) /= 0.D0 .OR. &
-              Hubbard_J0(nt) /= 0.D0 .OR. Hubbard_beta(nt) /= 0.D0 ) THEN
-            WRITE( stdout,'(5x,a6,12x,i1,2x,4f9.4)') atm(nt), Hubbard_L(nt), &
-               Hubbard_U(nt)*rytoev, Hubbard_alpha(nt)*rytoev, &
-               Hubbard_J0(nt)*rytoev, Hubbard_beta(nt)*rytoev
-         END IF
-      END DO
-      !
-   ELSEIF (lda_plus_u_kind == 1) THEN
-      CALL errore('do_cond', 'Full LDA+U not yet implemented in PWcond', 1)
-   ENDIF
-   !
-   WRITE( stdout,'(/)')
-   !
-ENDIF
-
 IF (nkpts==0) THEN
    time_reversal = .NOT. (noncolin .AND. domag)
    IF (ionode) THEN
@@ -414,9 +386,9 @@ IF (nkpts==0) THEN
          xyk(2,ik)=xk(2,ik)
       ENDDO
    ENDIF
-   CALL mp_bcast( nkpts, ionode_id )
-   CALL mp_bcast( xyk, ionode_id )
-   CALL mp_bcast( wkpt, ionode_id )
+   CALL mp_bcast( nkpts, ionode_id, world_comm )
+   CALL mp_bcast( xyk, ionode_id, world_comm )
+   CALL mp_bcast( wkpt, ionode_id, world_comm )
 ELSE
    tk_plot = 0
 ENDIF
@@ -433,8 +405,8 @@ ELSE
    start_k = 1
    last_k = nkpts
 ENDIF
-CALL mp_bcast( start_k, ionode_id )
-CALL mp_bcast( last_k, ionode_id )
+CALL mp_bcast( start_k, ionode_id, world_comm )
+CALL mp_bcast( last_k, ionode_id, world_comm )
 
   !!! RECOVER
   ! Simple restart mechanism for transmission calculations
@@ -522,7 +494,7 @@ CALL mp_bcast( last_k, ionode_id )
          IF ( ios .EQ. 0 ) THEN
             WRITE(stdout,'(a24, 2f12.7,/)') 'E-Ef(ev), T = ',earr(ien),tk
             tran_tot(ien) = tran_tot(ien) + wkpt(ik)*tk
-            !CALL mp_bcast( tran_tot(ien), ionode_id )
+            !CALL mp_bcast( tran_tot(ien), ionode_id, world_comm )
             CYCLE
          ! if not, do the actual calculation
          ELSE
@@ -567,12 +539,13 @@ CALL mp_bcast( last_k, ionode_id )
 
          WRITE(stdout,*) 'to transmit'
          CALL transmit(ik, ien, tk, .true.)
-         if (lorb) CALL transmit(ik, ien, tk, .false.)
-
          !
          ! To add T(k) to the total T
          !
          tran_tot(ien) = tran_tot(ien) + wkpt(ik)*tk
+         if (tk_plot.gt.0) tran_k(ik) = tk
+         if (lorb) CALL transmit(ik, ien, tk, .false.)
+
          !
          !!! RECOVER
          ! if recover is enabled, save the partial transmission on file,
@@ -589,9 +562,6 @@ CALL mp_bcast( last_k, ionode_id )
          ENDIF
          !!!
 
-         if (tk_plot.gt.0) tran_k(ik) = tk
-         tran_tot(ien) = tran_tot(ien) + wkpt(ik)*tk
-
       ENDIF
 
       if (loop_ek) CALL free_mem
@@ -601,6 +571,8 @@ CALL mp_bcast( last_k, ionode_id )
     if (ikind.ne.0.and.tk_plot.gt.0.and.ionode) &
              CALL summary_tran_k(ien,nk1ts,nk2ts,k1ts,k2ts)
 
+    if (.not.loop_ek) CALL free_mem
+
   ENDDO
 
   IF(ikind.ne.0.and.ionode) CALL summary_tran_tot()
