@@ -21,7 +21,7 @@ SUBROUTINE local (ien)
   USE io_files
   USE cond
   !
-  USE mp_global, ONLY : intra_pool_comm
+  USE mp_pools, ONLY : intra_pool_comm
   !
 
   IMPLICIT NONE
@@ -161,13 +161,13 @@ subroutine local_1 (edummy, nrz, vppot, n2d, psibase)
   USE kinds, only : DP
   USE cell_base, ONLY : at, tpiba2
   USE noncollin_module, ONLY : npol
-  USE mp_global,        ONLY : nproc, me_pool, root_pool
+  USE mp_world,        ONLY : world_comm, nproc
+  USE mp_pools,        ONLY : me_pool, root_pool, intra_pool_comm
   USE mp,         ONLY : mp_barrier, mp_bcast
   USE io_global, ONLY : ionode, ionode_id
   USE parallel_include
   use cond, only : nrx, nry, ngper, gper, ewind, epsproj
   !
-  USE mp_global, ONLY : intra_pool_comm
   !
   IMPLICIT NONE
 
@@ -280,9 +280,9 @@ subroutine local_1 (edummy, nrz, vppot, n2d, psibase)
   ENDDO
 
 #ifdef __MPI
-  CALL mp_barrier()
-  CALL mp_bcast(n2d,ionode_id)
-  CALL mp_bcast(psibase,ionode_id)
+  CALL mp_barrier(world_comm)
+  CALL mp_bcast(n2d,ionode_id, world_comm)
+  CALL mp_bcast(psibase,ionode_id, world_comm)
 #endif
 
   deallocate( gp )
@@ -302,7 +302,8 @@ subroutine local_2(nrz, nrzp, vppot, psiper, zkr)
   USE noncollin_module, ONLY : npol
   use cond, only : nrx, nry, ngper, n2d, gper, newbg
   !
-  USE mp_global, ONLY : intra_pool_comm
+  USE mp_pools, ONLY : intra_pool_comm
+  USE mp_world, ONLY : world_comm
   !
 
   IMPLICIT NONE
@@ -390,7 +391,7 @@ subroutine local_2(nrz, nrzp, vppot, psiper, zkr)
   ENDDO
 
 #ifdef __MPI
-  CALL mp_barrier()
+  CALL mp_barrier(world_comm)
 #endif
 
   deallocate(amat)
